# 微盛，企业管家 https://platform.wshoto.com
from lazysdk import lazyrequests
import copy


default_headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate, zstd",
        "Accept-Language": "en-US,en;q=0.5",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "Host": "platform.wshoto.com",
        "Origin": "https://platform.wshoto.com",
        "Pragma": "no-cache",
        "Referer": "https://platform.wshoto.com/index/dashboard",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "TE": "trailers",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:139.0) Gecko/20100101 Firefox/139.0",
        "x-admin-header": "1",
        "x-clientType-header": "pc",
        "x-header-host": "platform.wshoto.com",
    }


def dashboard(
        authorization: str
):
    url = "https://platform.wshoto.com/bff/index/private/pc/dashboard?saMode=SECRET"
    headers = copy.deepcopy(default_headers)
    headers["Authorization"] = authorization
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        headers=headers
    )


def material_package(
        authorization: str,
        search_package_name: str = ""
):
    """
    【内容中心】/【组合素材】/【配置素材合集】/查询
    :param authorization:
    :param search_package_name: 被查询的素材合集名称
    :return:
    """
    url = "https://platform.wshoto.com/bff/content/private/pc/material/package/packageQuery"
    headers = copy.deepcopy(default_headers)
    headers["Authorization"] = authorization
    data = {
        "pageSize": 1000,
        "pageIndex": 1,
        "searchPackageName": search_package_name,
        "isManager": 1,
        "isContainsNoUse": True,
        "isContainsStop": True,
        "businessType": 14,
        "isShowRecommend": True,
        "isScope": False
    }
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        headers=headers,
        json=data
    )


def create_material_package(
        authorization: str,
        name: str
):
    """
    【内容中心】/【组合素材】/【配置素材合集】/【+添加素材合集】
    :param authorization:
    :param name: 素材合集名称
    :return: {"code":"00000","msg":"OK","data":{"id":"2000222213115036674"}}
    """
    url = "https://platform.wshoto.com/bff/content/private/pc/materialCategory/create"
    headers = copy.deepcopy(default_headers)
    headers["Authorization"] = authorization
    data = {
        "name": name,
        "businessType":14,
        "editStatus":0
    }
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        headers=headers,
        json=data
    )


class WshotoCrawler:
    def __init__(
            self,
            authorization: str,
            headers: dict = None,
    ):
        if headers is None:
            headers = default_headers
        self.authorization = authorization
        self.headers = headers
        self.headers["Authorization"] = authorization

    def upload_file(
            self,
            file_path: str,
    ):
        """
        上传文件
        :param file_path: 文件路径
        :return:
        """
        url = "https://platform.wshoto.com/bff/content/private/pc/file/upload"
        headers = copy.deepcopy(self.headers)

        # 以二进制模式打开图片文件
        files = {'file': open(file_path, 'rb')}
        return lazyrequests.lazy_requests(
            method="POST",
            url=url,
            headers=headers,
            files=files
        )



from lazysdk import lazyrequests
from lazysdk import lazytime
import copy


default_headers = {
        "Host": "ad.qq.com",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:123.0) Gecko/20100101 Firefox/123.0",
        "Accept": "application/json, text/javascript, */*; q=0.01",
        "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        "Accept-Encoding": "gzip, deflate",
        "Content-Type": "application/json",
        "X-Requested-With": "XMLHttpRequest",
        "Connection": "keep-alive",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "Pragma": "no-cache",
        "Cache-Control": "no-cache",
        "TE": "trailers"
    }  # 默认的header


def new_account_list(
        cookie: str,
        user_id: int,
        business_id: int,
        start_date: str = None,
        end_date: str = None,
        page: int = 1,
        page_size: int = 20,
        account_id: int = None,  # 支持按户id搜索
        account_status: int = 1,
        sort_seq: str = None,
        sort_field: str = None,
        platform_type: int = 1
):
    """
    概览-账户 页面按照消耗降序排序的数据
    :param cookie:
    :param user_id: 登录用户的id
    :param business_id: 大户id
    :param start_date:
    :param end_date:
    :param page:
    :param page_size:
    :param account_id: 子户id
    :param account_status: 账户状态
        1：有效
        2：待审核
        3：审核不通过
        4：封停
        21：临时冻结
    :return:
    """
    if not start_date:
        start_date = lazytime.get_date_string(days=-1)
    if not end_date:
        end_date = lazytime.get_date_string(days=-1)
    url = "https://ad.qq.com/tap/v1/account_daily_report/new_account_list?unicode=1&post_format=json"
    temp_headers = copy.deepcopy(default_headers)
    temp_headers["Cookie"] = cookie
    data = {
        "new_source": 1,
        "user_id": user_id,
        "page": page,
        "page_size": page_size,
        "need_sync": True,
        "sync_param_ready": True,
        "business_id_list": [
            business_id
        ],
        "dynamic_field_list": [
            "corporation_name",
            "corporation_alias",
            "rule_target_enable",
            "derive_status",
            "comment",  # 标签
            "cost"  # 消耗
        ],
        "time_line": "REQUEST_TIME",
        "start_date_millons": lazytime.get_date2timestamp(date=start_date) * 1000,  # 开始时间的时间戳
        "end_date_millons": lazytime.get_date2timestamp(date=end_date) * 1000,  # 结束时间的时间戳
        "account_status": account_status,
        "platform_type": platform_type,
        "use_top_sort": True,
        "filter_empty_data": 0
    }
    if account_id:
        data["account_id"] = [account_id]
    if sort_seq:
        data["sort_seq"] = sort_seq  # desc:降序排序，会自动过滤0数据
    if sort_field:
        data["sort_field"] = sort_field  # cost:按照消耗排序
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        headers=temp_headers,
        json=data
    )


def account_list_v30(
        cookie: str,
        user_id: int,
        business_id: int,
        start_date: str = None,
        end_date: str = None,
        page: int = 1,
        page_size: int = 20,
        account_id: int = None,  # 支持按户id搜索
        account_status: int = 1,
        sort_seq: str = None,
        sort_field: str = None,
        platform_type: int = 1
):
    """
    概览-账户 ADQ3.0账户列表
    :param cookie:
    :param user_id: 登录用户的id
    :param business_id: 大户id
    :param start_date:
    :param end_date:
    :param page:
    :param page_size:
    :param account_id: 子户id
    :param account_status: 账户状态
        1：有效
        2：待审核
        3：审核不通过
        4：封停
        21：临时冻结
    :return:
    """
    if not start_date:
        start_date = lazytime.get_date_string(days=-1)
    if not end_date:
        end_date = lazytime.get_date_string(days=-1)
    url = "https://ad.qq.com/tap/v1/account_daily_report/new_account_list?unicode=1&post_format=json"
    temp_headers = copy.deepcopy(default_headers)
    temp_headers["Cookie"] = cookie
    data = {
        "new_source": 1,
        "user_id": user_id,
        "page": page,
        "page_size": page_size,
        "need_sync": True,
        "sync_param_ready": True,
        "business_id_list": [
            business_id
        ],
        "dynamic_field_list": [
            "corporation_name",
            "corporation_alias",
            "rule_target_enable",
            "derive_status",
            "comment",  # 标签
            "cost"  # 消耗
        ],
        "time_line": "REQUEST_TIME",
        "start_date_millons": lazytime.get_date2timestamp(date=start_date) * 1000,  # 开始时间的时间戳
        "end_date_millons": lazytime.get_date2timestamp(date=end_date) * 1000,  # 结束时间的时间戳
        "account_status": account_status,
        "platform_type": platform_type,
        "use_top_sort": True,
        "filter_empty_data": 0
    }
    if account_id:
        data["account_id"] = [account_id]
    if sort_seq:
        data["sort_seq"] = sort_seq  # desc:降序排序，会自动过滤0数据
    if sort_field:
        data["sort_field"] = sort_field  # cost:按照消耗排序
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        headers=temp_headers,
        json=data
    )



from lazysdk import lazyrequests
from lazysdk import lazybase64
from lazysdk import lazytime


def make_auth(
        keyid,
        secret_key
):
    """
    生成校验字符串
    :param keyid:
    :param secret_key:
    :return:
    """
    authorization = f"{keyid}:{secret_key}"
    return f"Basic {lazybase64.lazy_b64encode(authorization)}"


def apps(
        organization_id,
        keyid,
        secret_key,
        timeout: int = 10
):
    """
    获取app列表
    https://services.docs.unity.com/advertise/v1/index.html#section/Get-Started/First-Call:-List-Apps
    :param organization_id:
    :param keyid:
    :param secret_key:
    :param timeout:
    :return:
    """
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        headers=headers,
        timeout=timeout,
    )


def list_campaigns(
        organization_id,
        app_id,
        keyid,
        secret_key,
        timeout: int = 10
):
    """
    获取Campaigns列表
    https://services.docs.unity.com/advertise/v1/index.html#tag/Campaigns
    :param organization_id:
    :param app_id:
    :param keyid:
    :param secret_key:
    :return:
    """
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps/{app_id}/campaigns"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        headers=headers,
        timeout=timeout,
    )


def get_campaign(
        organization_id,
        app_id,
        campaign_id,
        keyid,
        secret_key,
        include_fields: list = None,
        timeout: int = 10
):
    """
    获取Campaign信息
    https://services.docs.unity.com/advertise/v1/index.html#tag/Campaigns/operation/advertise_getCampaign
    :param organization_id:
    :param app_id:
    :param campaign_id:
    :param keyid:
    :param secret_key:
    :param include_fields: ["cpiBids", "sourceBids", "roasBids", "retentionBids", "eventOptimizationBids", "budget"]
    :return:
    """
    default_include_fields = ["cpiBids", "sourceBids", "roasBids", "retentionBids", "eventOptimizationBids", "budget"]
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps/{app_id}/campaigns/{campaign_id}"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    if include_fields:
        pass
    else:
        include_fields = default_include_fields
    params_list = list()
    for each in include_fields:
        params_list.append(f"includeFields={each}")
    params_str = "&".join(params_list)
    return lazyrequests.lazy_requests(
        method="GET",
        url=f"{url}?{params_str}",
        headers=headers,
        timeout=timeout,
    )


def get_budget(
        organization_id,
        app_id,
        campaign_id,
        keyid,
        secret_key,
        timeout: int = 10
):
    """
    获取 Campaign budget
    https://services.docs.unity.com/advertise/v1/index.html#tag/Campaigns/operation/advertise_getCampaignBudget
    :param organization_id:
    :param app_id:
    :param campaign_id:
    :param keyid:
    :param secret_key:
    :return:
    """
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps/{app_id}/campaigns/{campaign_id}/budget"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        headers=headers,
        timeout=timeout,
    )


def get_targeting_options(
        organization_id,
        app_id,
        campaign_id,
        keyid,
        secret_key,
        timeout: int = 10
):
    """
    Get targeting options
    https://services.docs.unity.com/advertise/v1/index.html#tag/Campaigns/operation/advertise_getTargeting
    :param organization_id:
    :param app_id:
    :param campaign_id:
    :param keyid:
    :param secret_key:
    :return:
    """
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps/{app_id}/campaigns/{campaign_id}/targeting"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        headers=headers,
        timeout=timeout,
    )


def update_targeting_options(
        organization_id,
        app_id,
        campaign_id,
        keyid,
        secret_key,
        allow_list: list = None,
        block_list: list = None,
        iso_os_min: str = None,
        timeout: int = 10
):
    """
    Update targeting options
    https://services.docs.unity.com/advertise/v1/index.html#tag/Campaigns/operation/advertise_updateTargeting
    :param organization_id:
    :param app_id:
    :param campaign_id:
    :param keyid:
    :param secret_key:

    :param allow_list:
    :param block_list:
    :param iso_os_min:
    :return:
    """
    url = f"https://services.api.unity.com/advertise/v1/organizations/{organization_id}/apps/{app_id}/campaigns/{campaign_id}/targeting"
    headers = {"Authorization": make_auth(keyid=keyid, secret_key=secret_key)}
    data = {}
    if allow_list or block_list:
        data["appTargeting"] = {}
        if allow_list:
            data["appTargeting"]["allowList"] = allow_list
        if block_list:  # 黑名单
            data["appTargeting"]["blockList"] = block_list
    if iso_os_min:
        data["deviceTargeting"] = {}
        if iso_os_min:
            data["deviceTargeting"]["osMin"] = iso_os_min
    return lazyrequests.lazy_requests(
        method="PATCH",
        url=url,
        headers=headers,
        json=data,
        timeout=timeout,
    )


def reports(
        organization_id,
        keyid,
        secret_key,
        start: str,
        end: str,
        scale: str = "day",
        metrics: list = None,
        breakdowns: list = None,
        timeout: int = 60
):
    """
    https://services.docs.unity.com/statistics/index.html#tag/Acquisitions/operation/stats_acquisition
    :param metrics:
        starts
        views
        clicks
        installs
        spend
        cpi
        ctr
        cvr
        ecpm
        d0AdRevenue
        d1AdRevenue
        d3AdRevenue
        d7AdRevenue
        d14AdRevenue
        d0AdRevenueRoas
        d1AdRevenueRoas
        d3AdRevenueRoas
        d7AdRevenueRoas
        d14AdRevenueRoas
        d0IapRevenue
        d1IapRevenue
        d3IapRevenue
        d7IapRevenue
        d14IapRevenue
        d0IapRoas
        d1IapRoas
        d3IapRoas
        d7IapRoas
        d14IapRoas
        d0Purchases
        d1Purchases
        d3Purchases
        d7Purchases
        d14Purchases
        d0UniquePurchasers
        d1UniquePurchasers
        d3UniquePurchasers
        d7UniquePurchasers
        d14UniquePurchasers
        d0Retained
        d1Retained
        d3Retained
        d7Retained
        d14Retained
        d0RetentionRate
        d1RetentionRate
        d3RetentionRate
        d7RetentionRate
        d14RetentionRate
        d0TotalRoas
        d1TotalRoas
        d3TotalRoas
        d7TotalRoas
        d14TotalRoas
        d0LevelComplete
        d1LevelComplete
        d3LevelComplete
        d7LevelComplete
        d14LevelComplete
        d0CostPerLevelComplete
        d1CostPerLevelComplete
        d3CostPerLevelComplete
        d7CostPerLevelComplete
        d14CostPerLevelComplete
        d0LevelCompleteRate
        d1LevelCompleteRate
        d3LevelCompleteRate
        d7LevelCompleteRate
        d14LevelCompleteRate
    :param breakdowns:
        app,
        campaign,
        country,
        creativePack,
        creativePackType,
        osVersion,
        platform,
        sourceAppId,
        store,
        targetGame,
        eventType,
        eventName
    :return:
    """
    authorization = f"Basic {keyid}:{secret_key}"
    url = f"https://services.api.unity.com/advertise/stats/v2/organizations/{organization_id}/reports/acquisitions"
    params = {
        "scale": scale,  # "summary" "hour" "day" "week" "month"
        "format": "json"
    }

    if not metrics:
        metrics = [
            "spend"
        ]
    if not breakdowns:
        breakdowns = [
            "country"
        ]

    params["breakdowns"] = ",".join(breakdowns)
    params["metrics"] = ",".join(metrics)
    params["start"] = start
    params["end"] = end

    headers = {"Authorization": authorization}
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params,
        headers=headers,
        return_json=False,
        timeout=timeout
    )



from lazysdk import lazyrequests
import showlog

from lazysdk import lazytime
import json
import random
import copy
import time


"""
2024-04-11 全面升级至3.0版本 https://developers.e.qq.com/v3.0/docs/api
"""


def make_nonce():
    """
    参考示例代码的生成一个随机数
    :return:
    """
    return str(time.time()) + str(random.randint(0, 999999))


def oauth_token2(
        app_id,
        app_secret,
        redirect_uri,
        grant_type='authorization_code',
        auth_code=None,
        refresh_token=None,
):
    """
    OAuth 2.0 授权
    获取/刷新token
    相关文档：https://developers.e.qq.com/docs/start/authorization
    :param auth_code:
    :param app_id:
    :param app_secret:
    :param grant_type: 请求的类型，可选值：authorization_code（授权码方式获取 token）、refresh_token（刷新 token）
    :param refresh_token:
    :param redirect_uri:
    :return:
    """
    redirect_uri = f'{redirect_uri}?app_id={app_id}'

    url = 'https://api.e.qq.com/oauth/token'
    params = {
        'client_id': app_id,
        'client_secret': app_secret,
        'grant_type': grant_type
    }
    if auth_code:
        params['authorization_code'] = auth_code
    if refresh_token:
        params['refresh_token'] = refresh_token
    if redirect_uri:
        params['redirect_uri'] = redirect_uri

    for k in params:
        if type(params[k]) is not str:
            params[k] = json.dumps(params[k])

    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params
    )


def oauth_token3(
        app_id,
        app_secret,
        redirect_uri=None,
        access_token=None,
        grant_type='authorization_code',
        auth_code=None,
        refresh_token=None,
):
    """
    获取/刷新token
    相关文档：https://developers.e.qq.com/v3.0/docs/api/oauth/token
    :param access_token:
    :param auth_code:
    :param app_id:
    :param app_secret:
    :param grant_type: 请求的类型，可选值：authorization_code（授权码方式获取 token）、refresh_token（刷新 token）
    :param refresh_token:
    :param redirect_uri: 回调地址
    :return:
    """
    params = {
        'client_id': app_id,
        'client_secret': app_secret,
        'grant_type': grant_type
    }
    if access_token:
        # OAuth 相关接口无需提供 access_token、timestamp、nonce 等通用请求参数。
        params['access_token'] = access_token
        params['timestamp'] = int(time.time())
        params['nonce'] = make_nonce()
        url = 'https://api.e.qq.com/v3.0/oauth/token'
    else:
        url = 'https://api.e.qq.com/oauth/token'
    if auth_code:
        params['authorization_code'] = auth_code
    if refresh_token:
        params['refresh_token'] = refresh_token
    if redirect_uri:
        redirect_uri = f'{redirect_uri}?app_id={app_id}'
        params['redirect_uri'] = redirect_uri

    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params
    )


def get_organization_account_relation(
        access_token: str,
        account_id=None,
        cursor=None,
        page: int = 1,
        page_size: int = 100,
        pagination_mode: str = "PAGINATION_MODE_CURSOR"
):
    """
    版本：3.0
    获取子账号列表
    这里获取子账户主要使用这个方法
    https://developers.e.qq.com/v3.0/docs/api/organization_account_relation/get
    :param access_token:
    :param account_id:
    :param cursor:
    :param page:
    :param page_size: 最小值 1，最大值 100
    :param pagination_mode: 分页方式，注意，为PAGINATION_MODE_NORMAL时，不能获取大于1000条的记录
    :return:
    """
    url = 'https://api.e.qq.com/v3.0/organization_account_relation/get'
    params = {
        'access_token': access_token,
        'timestamp': int(time.time()),
        'nonce': make_nonce(),
        "pagination_mode": pagination_mode,
        "page_size": page_size
    }
    if pagination_mode == "PAGINATION_MODE_NORMAL":
        params["page"] = page
    elif pagination_mode == "PAGINATION_MODE_CURSOR":
        params["cursor"] = cursor
    else:
        showlog.warning("pagination_mode参数错误")
        return

    if account_id:
        params["account_id"] = account_id
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params
    )


def get_advertiser_daily_budget(
        access_token: str,
        account_id
):
    """
    版本：3.0
    获取广告账户日预算
    https://developers.e.qq.com/v3.0/docs/api/advertiser_daily_budget/get
    :param access_token:
    :param account_id:
    :return:

    应答示例
    {
        "code": 0,
        "message": "",
        "message_cn": "",
        "data": {
            "account_id": "<ACCOUNT_ID>",
            "daily_budget": 20000,
            "min_daily_budget": 10000
        }
    }
    """
    url = 'https://api.e.qq.com/v3.0/advertiser_daily_budget/get'
    params = {
        'access_token': access_token,
        'timestamp': int(time.time()),
        'nonce': make_nonce(),

        "account_id": account_id,
        "fields": [
            "account_id",
            "daily_budget"
        ]
    }
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params
    )


def update_daily_budget(
        access_token: str,
        account_id: int = None,
        daily_budget: int = None,
        update_daily_budget_spec: list = None
):
    """
    版本：3.0
    批量修改广告主日限额
    https://developers.e.qq.com/v3.0/docs/api/advertiser/update_daily_budget
    :param access_token:
    :param account_id:
    :param daily_budget: 账户预算，单位为分
    :param update_daily_budget_spec: 任务列表，[{"account_id":"aaa","daily_budget": 100},{"account_id":"bbb","daily_budget": 100}]
    :return:

    应答示例
    {
        "code": 0,
        "message": "",
        "message_cn": "",
        "data": {
            "list": [
                {
                    "code": 0,
                    "message": "",
                    "message_cn": "",
                    "account_id": "<ACCOUNT_ID>"
                }
            ],
            "fail_id_list": []
        }
    }
    """
    url = 'https://api.e.qq.com/v3.0/advertiser/update_daily_budget'
    params = {
        'access_token': access_token,
        'timestamp': int(time.time()),
        'nonce': make_nonce()
    }
    data = dict()
    if update_daily_budget_spec:
        data["update_daily_budget_spec"] = update_daily_budget_spec
    else:
        data["update_daily_budget_spec"] = [
            {
                "account_id": account_id,
                "daily_budget": daily_budget
            }
        ]
    return lazyrequests.lazy_requests(
        method="POST",
        url=url,
        params=params,
        json=data
    )


class DevelopersEQQ:
    def __init__(
            self,
            access_token,
            user_token=None,
    ):
        self.access_token = access_token
        self.user_token = user_token

    def get_daily_reports(
            self,
            account_id,
            level: str,
            page: int = 1,
            page_size: int = 100,
            start_date: str = None,
            end_date: str = None,
            fields: list = None,
            group_by: list = None,
            filtering: list = None
    ):
        """
        数据洞察-广告数据洞察-获取日报表
        https://developers.e.qq.com/v3.0/docs/api/daily_reports/get
        :param account_id:
        :param level: 获取报表类型级别，当查询业务单元的报表时,level 只支持组件层级，枚举详情：https://developers.e.qq.com/v3.0/docs/enums#api_report_daily_level
        :param page:
        :param page_size:
        :param start_date:
        :param end_date:
        :param fields:
        :param group_by:
        :param filtering:
        :return:
        """
        url = 'https://api.e.qq.com/v3.0/daily_reports/get'

        if not start_date:
            start_date = lazytime.get_date_string(days=0)
        if not end_date:
            end_date = lazytime.get_date_string(days=0)
        if not fields:
            fields = [
                "account_id",
                "date",
                "cost"
            ]
        if not group_by:
            group_by = ["date"]
        parameters = {
            'access_token': self.access_token,
            'timestamp': int(time.time()),
            'nonce': str(time.time()) + str(random.randint(0, 999999)),

            "account_id": account_id,
            "level": level,
            "time_line": "REQUEST_TIME",
            "date_range": {
                "start_date": start_date,
                "end_date": end_date
            },
            "group_by": group_by,  # 聚合参数
            "order_by": [
                {
                    "sort_field": "cost",  # 排序字段
                    "sort_type": "DESCENDING"  # 排序方式:ASCENDING(升序)/DESCENDING(降序)
                }
            ],  # 排序字段
            "page": page,
            "page_size": page_size,
            "fields": fields  # 指定返回的字段列表，必需写，不写不返回数据，具体能写哪些，看文档
        }
        if filtering:
            parameters["filtering"] = filtering

        for k in parameters:
            if type(parameters[k]) is not str:
                parameters[k] = json.dumps(parameters[k])

        return lazyrequests.lazy_requests(
            method="GET",
            url=url,
            params=parameters,
        )

    def get_daily_reports_day_all(
            self,
            account_id,
            level: str,
            cost_min: int = None,
            start_date: str = None,
            end_date: str = None,
            fields: list = None,
            group_by: list = None,
    ):
        """
        开发文档：https://developers.e.qq.com/v3.0/docs/api/daily_reports/get
        :param level: 获取报表类型级别，当查询业务单元的报表时,level 只支持组件层级，枚举详情：https://developers.e.qq.com/v3.0/docs/enums#api_report_daily_level

        """
        task_data = list()
        if not fields:
            fields = [
                "date",  # 日期
                "account_id",  # 账号ID
                "cost",  # 花费，单位分
                "thousand_display_price",  # 千次展现均价，单位分
                "valid_click_count",  # 点击次数
                "conversions_count",  # 目标转化量
                "from_follow_uv",  # 公众号关注人数
                "dynamic_creative_id",  # 创意id
                "dynamic_creative_name",
                "scan_follow_user_count",  # 加企业微信客服人数。添加企微客服人数
                "cpc",  # 点击均价
                "scan_follow_user_cost",  # 加企业微信客服成本（人数）
                "income_val_1",  # 激活首日广告变现金额
            ]
        if not group_by:
            group_by = ["date", "dynamic_creative_id"]
        page = 1
        while True:
            showlog.info(f"正在采集第 {page} 页的数据...")
            response = self.get_daily_reports(
                account_id=account_id,
                level=level,
                fields=fields,
                group_by=group_by,
                page=page,
                start_date=start_date,
                end_date=end_date
            )
            if response.get('code') == 0:
                response_data = response.get('data')
                if response_data:
                    # print(response_data)
                    response_data_list = response_data.get('list')
                    page_info = response_data.get('page_info')
                    total_page = page_info.get('total_page')

                    if response_data_list:
                        showlog.info(f'获取到 {len(response_data_list)} 条记录...')
                        for each_data in response_data_list:
                            each_data_cost = each_data['cost'] / 100
                            each_data['cost'] = each_data_cost
                            each_data['thousand_display_price'] = each_data.get("thousand_display_price", 0) / 100
                            if each_data_cost >= cost_min or cost_min is None:
                                # print(each_data)
                                each_data["access_token"] = self.access_token
                                conversions_count = each_data.get('conversions_count', 0)  # 目标转化量
                                from_follow_uv = each_data.get('from_follow_uv', 0)  # 公众号关注人数
                                scan_follow_user_count = each_data.get('scan_follow_user_count', 0)  # 加企业微信客服人数
                                fans_add = conversions_count + from_follow_uv + scan_follow_user_count  # 进粉数
                                each_data["fans_add"] = fans_add
                                task_data.append(copy.deepcopy(each_data))
                            else:
                                continue
                    else:
                        showlog.warning(f'无数据，response: {response}')
                    if page >= total_page:
                        showlog.info("已采集到最后一页")
                        break
                    else:
                        page += 1
                else:
                    showlog.warning(f'response: {response}')
                    break
            else:
                showlog.warning(f'response: {response}')
                break
        return task_data

    def adgroups_get(
            self,
            account_id,
            page: int = 1,
            page_size: int = 100,
            fields: list = None,
            filtering: list = None,
            is_deleted: bool = False,
            pagination_mode: str = None,
            cursor: str = None
    ):
        """
        展示广告管理-广告-获取广告
        https://developers.e.qq.com/v3.0/docs/api/adgroups/get
        :param account_id:
        :param page:
        :param page_size:
        :param is_deleted: 是否已删除，true：是，false：否
        :param fields: 指定返回的字段列表
        :param pagination_mode: 分页方式，默认使用 PAGINATION_MODE_NORMAL，详见：https://developers.e.qq.com/v3.0/docs/enums#api_pagination_mode
        :param cursor: 游标值，游标翻页模式(PAGINATION_MODE_CURSOR)使用，第一次拉取无需填写、后续拉取传递上一次返回的 cursor 数值

        :param filtering:

        :return:
        """
        url = 'https://api.e.qq.com/v3.0/adgroups/get'
        if not fields:
            fields = [
                "account_id",
                "system_status",
                "configured_status"
            ]

        parameters = {
            'access_token': self.access_token,
            'timestamp': int(time.time()),
            'nonce': str(time.time()) + str(random.randint(0, 999999)),

            "account_id": account_id,
            "page": page,
            "page_size": page_size,
            "is_deleted": is_deleted,
            "fields": fields,  # 指定返回的字段列表，必需写，不写不返回数据，具体能写哪些，看文档

        }
        if pagination_mode is not None:
            parameters["pagination_mode"] = pagination_mode
        if cursor is not None:
            parameters["cursor"] = cursor
        if filtering:
            parameters["filtering"] = filtering

        for k in parameters:
            if type(parameters[k]) is not str:
                parameters[k] = json.dumps(parameters[k])

        return lazyrequests.lazy_requests(
            method="GET",
            url=url,
            params=parameters,
        )

    def adgroups_update(
            self,
            account_id,
            adgroup_id,
            configured_status: str = None,
            user_token: str = None,
    ):
        """
        展示广告管理-广告-更新广告
        https://developers.e.qq.com/v3.0/docs/api/adgroups/update
        :param account_id: [必填]
        :param adgroup_id: [必填]
        :param configured_status: 客户设置的状态，ADX 程序化广告不可填写提交，可选值：{ AD_STATUS_NORMAL, AD_STATUS_SUSPEND }

        :return:
        """
        url = 'https://api.e.qq.com/v3.0/adgroups/update'

        parameters = {
            'access_token': self.access_token,
            'timestamp': int(time.time()),
            'nonce': str(time.time()) + str(random.randint(0, 999999)),
        }
        if user_token is not None:
            parameters["user_token"] = user_token
        else:
            parameters["user_token"] = self.user_token

        data = {
            "account_id": account_id,
            "adgroup_id": adgroup_id,
        }
        if configured_status is not None:
            data["configured_status"] = configured_status

        for k in parameters:
            if type(parameters[k]) is not str:
                parameters[k] = json.dumps(parameters[k])

        return lazyrequests.lazy_requests(
            method="POST",
            url=url,
            params=parameters,
            json=data
        )

    def dynamic_creatives_get(
            self,
            account_id,
            page: int = 1,
            page_size: int = 100,
            fields: list = None,
            filtering: list = None,
            is_deleted: bool = False,
            pagination_mode: str = None,
            cursor: str = None
    ):
        """
        展示广告管理-创意-获取创意
        https://developers.e.qq.com/v3.0/docs/api/dynamic_creatives/get
        :param account_id:
        :param page:
        :param page_size:
        :param is_deleted: 是否已删除，true：是，false：否
        :param fields: 指定返回的字段列表
        :param pagination_mode: 分页方式，默认使用 PAGINATION_MODE_NORMAL，详见：https://developers.e.qq.com/v3.0/docs/enums#api_pagination_mode
        :param cursor: 游标值，游标翻页模式(PAGINATION_MODE_CURSOR)使用，第一次拉取无需填写、后续拉取传递上一次返回的 cursor 数值

        :param filtering:

        :return:
        """
        url = 'https://api.e.qq.com/v3.0/dynamic_creatives/get'
        method = "GET"

        if not fields:
            fields = [
                "account_id",
                "dynamic_creative_id",
                "dynamic_creative_name",
                "configured_status",
                "system_status",
                "is_deleted"
            ]

        parameters = {
            'access_token': self.access_token,
            'timestamp': int(time.time()),
            'nonce': str(time.time()) + str(random.randint(0, 999999)),

            "account_id": account_id,
            "page": page,
            "page_size": page_size,
            "is_deleted": is_deleted,
            "fields": fields,  # 指定返回的字段列表，必需写，不写不返回数据，具体能写哪些，看文档

        }
        if pagination_mode is not None:
            parameters["pagination_mode"] = pagination_mode
        if cursor is not None:
            parameters["cursor"] = cursor
        if filtering:
            parameters["filtering"] = filtering

        for k in parameters:
            if type(parameters[k]) is not str:
                parameters[k] = json.dumps(parameters[k])

        return lazyrequests.lazy_requests(
            method=method,
            url=url,
            params=parameters,
        )

    def dynamic_creatives_update(
            self,
            account_id,
            dynamic_creative_id,
            configured_status: str = None,
            user_token: str = None,
    ):
        """
        展示广告管理-创意-更新创意
        https://developers.e.qq.com/v3.0/docs/api/dynamic_creatives/update
        :param account_id: [必填]
        :param dynamic_creative_id: [必填]
        :param configured_status: 客户设置的状态，ADX 程序化广告不可填写提交，可选值：{ AD_STATUS_NORMAL, AD_STATUS_SUSPEND }

        :return:
        """
        url = 'https://api.e.qq.com/v3.0/dynamic_creatives/update'
        method = "POST"

        parameters = {
            'access_token': self.access_token,
            'timestamp': int(time.time()),
            'nonce': str(time.time()) + str(random.randint(0, 999999)),
        }
        if user_token is not None:
            parameters["user_token"] = user_token
        else:
            parameters["user_token"] = self.user_token

        data = {
            "account_id": account_id,
            "dynamic_creative_id": dynamic_creative_id,
        }
        if configured_status is not None:
            data["configured_status"] = configured_status

        for k in parameters:
            if type(parameters[k]) is not str:
                parameters[k] = json.dumps(parameters[k])

        return lazyrequests.lazy_requests(
            method=method,
            url=url,
            params=parameters,
            json=data
        )



from lazysdk import lazyrequests
import showlog


def lookup(
        _id: int = None,
        track_id: int = None,
        bundle_id: str = None,
        country: str = None,
        timeout: int = 5
):
    """
    获取app信息/开发者信息
    :param _id: app id/开发者id
    :param track_id:
    :param bundle_id:
    :param country:
    :param timeout:
    :return:
    """
    params = dict()
    url = "https://itunes.apple.com/lookup"
    if country:
        params['country'] = country

    if _id is not None:
        params["id"] = _id
    if track_id is not None:
        params["id"] = track_id
        # url = f"https://itunes.apple.com/lookup?id={track_id}"
    if bundle_id is not None:
        params["bundleId"] = bundle_id
        # url = f"https://itunes.apple.com/lookup?bundleId={bundle_id}"
    return lazyrequests.lazy_requests(
        method="GET",
        url=url,
        params=params,
        timeout=timeout
    )


def lookup_auto(
        input_str: str
):
    """
    输入待查询的字符串，自动处理查询结果
    :param input_str:
    :return:
    """
    bundle_id = None
    track_id = None
    if input_str.startswith("id") and input_str[2:].isdigit():
        # 以id开头，后续为数字的格式，判断为track_id
        showlog.info(f"输入 [{input_str}] 类型为 [id+track_id]")
        track_id = input_str[2:]
    elif input_str.startswith("tempBundleId"):
        showlog.info(f"输入 [{input_str}] 类型为 [tempBundleId]")
        bundle_id = input_str
    elif input_str.isdigit():  # 全部为数字
        showlog.info(f"输入 [{input_str}] 类型为 [track_id]")
        track_id = input_str
    else:
        showlog.info(f"输入 [{input_str}] 类型为 [bundle_id]")
        bundle_id = input_str

    if track_id:
        if isinstance(track_id, str):
            return {"track_id": track_id, "lookup_res": lookup(track_id=int(track_id))}
        elif isinstance(track_id, int):
            return {"track_id": track_id, "lookup_res": lookup(track_id=track_id)}
        else:
            return None
    elif bundle_id:
        return {"bundle_id": bundle_id, "lookup_res": lookup(bundle_id=bundle_id)}
    else:
        return None
